<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Ultravel
 * @since Ultravel 1.0.0
 */

$options = ultravel_get_theme_options();


if ( ! function_exists( 'ultravel_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Ultravel 1.0.0
	 */
	function ultravel_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'ultravel_doctype', 'ultravel_doctype', 10 );


if ( ! function_exists( 'ultravel_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'ultravel_before_wp_head', 'ultravel_head', 10 );

if ( ! function_exists( 'ultravel_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'ultravel' ); ?></a>

		<?php
	}
endif;
add_action( 'ultravel_page_start_action', 'ultravel_page_start', 10 );

if ( ! function_exists( 'ultravel_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_header_start() {
		?>
		<div class="menu-overlay"></div>
		<header id="masthead" class="site-header" role="banner">
		<?php
	}
endif;
add_action( 'ultravel_header_action', 'ultravel_header_start', 20 );

if ( ! function_exists( 'ultravel_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'ultravel_page_end_action', 'ultravel_page_end', 10 );

if ( ! function_exists( 'ultravel_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_site_branding() {
		$options  = ultravel_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="wrapper">
		<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-identity">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( ultravel_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
			<?php endif; ?>
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'ultravel_header_action', 'ultravel_site_branding', 20 );

if ( ! function_exists( 'ultravel_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_site_navigation() {
		$options = ultravel_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<?php
				echo ultravel_get_svg( array( 'icon' => 'menu' ) );
				echo ultravel_get_svg( array( 'icon' => 'close' ) );
				?>					
			</button>

			<?php  
				$social = '';
				if ( $options['social_nav_enable'] ) :            	
					$social .= '<li class="social-menu"><div class="social-icons">';
					$social .= wp_nav_menu( array(
            			'theme_location' => 'social',
            			'container' => false,
            			'menu_class' => '',
            			'echo' => false,
            			'fallback_cb' => 'ultravel_menu_fallback_cb',
            			'depth' => 1,
            			'link_before' => '<span class="screen-reader-text">',
						'link_after' => '</span>',
            		) );
					$social .= '</div></li>';
                endif;

                $cart = '';
				if ( $options['cart_nav_enable'] && class_exists('WooCommerce') ) :            	
					$cart .= '<li class="cart-count">';
					$cart .= '<a href="'.wc_get_cart_url().'" class="count">';
					$cart .= '<svg viewBox="0 -31 512.00033 512" class="icon-location"><path d="m166 300.003906h271.003906c6.710938 0 12.597656-4.4375 14.414063-10.882812l60.003906-210.003906c1.289063-4.527344.40625-9.390626-2.433594-13.152344-2.84375-3.75-7.265625-5.964844-11.984375-5.964844h-365.632812l-10.722656-48.25c-1.523438-6.871094-7.617188-11.75-14.648438-11.75h-91c-8.289062 0-15 6.710938-15 15 0 8.292969 6.710938 15 15 15h78.960938l54.167968 243.75c-15.9375 6.929688-27.128906 22.792969-27.128906 41.253906 0 24.8125 20.1875 45 45 45h271.003906c8.292969 0 15-6.707031 15-15 0-8.289062-6.707031-15-15-15h-271.003906c-8.261719 0-15-6.722656-15-15s6.738281-15 15-15zm0 0"></path><path d="m151 405.003906c0 24.816406 20.1875 45 45.003906 45 24.8125 0 45-20.183594 45-45 0-24.8125-20.1875-45-45-45-24.816406 0-45.003906 20.1875-45.003906 45zm0 0"></path><path d="m362.003906 405.003906c0 24.816406 20.1875 45 45 45 24.816406 0 45-20.183594 45-45 0-24.8125-20.183594-45-45-45-24.8125 0-45 20.1875-45 45zm0 0"></path>
                        </svg>';
					$cart .= '<span>'.WC()->cart->get_cart_contents_count().'</span>';
					$cart .= '</li>';
                endif;

                 $search = '';
				if ( $options['search_nav_enable'] ) :            	
					$search .= sprintf(
					'<li class="search-menu"><a href="#" title="%1$s">%2$s%3$s</a><div id="search">%4$s</div>',
					esc_attr__('search','ultravel'),
					ultravel_get_svg( array( 'icon' => 'search' ) ), 
					ultravel_get_svg( array( 'icon' => 'close' ) ), 
					get_search_form( $echo = false )
				);
                endif;

        		$defaults = array(
        			'theme_location' => 'primary',
        			'container' => 'div',
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'ultravel_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $cart . $social . '</ul>',
        		);
        	
        		wp_nav_menu( $defaults );
        	?>
		</nav><!-- #site-navigation -->
		</div><!-- .wrapper -->
		<?php
	}
endif;
add_action( 'ultravel_header_action', 'ultravel_site_navigation', 30 );


if ( ! function_exists( 'ultravel_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_header_end() {
		?>
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'ultravel_header_action', 'ultravel_header_end', 50 );

if ( ! function_exists( 'ultravel_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'ultravel_content_start_action', 'ultravel_content_start', 10 );

if ( ! function_exists( 'ultravel_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_header_image() {
		if ( ultravel_is_frontpage() )
			return;
		$header_image = get_header_image();
		$class = '';
		if ( is_singular() ) :
			$class = ( has_post_thumbnail() || ! empty( $header_image ) ) ? '' : 'header-media-disabled';
		else :
			$class = ! empty( $header_image ) ? '' : 'header-media-disabled';
		endif;
		
		if ( is_singular() && has_post_thumbnail() ) : 
			$header_image = get_the_post_thumbnail_url( get_the_id(), 'full' );
    	endif; ?>

    	<div id="page-site-header" class="relative <?php echo esc_attr( $class ); ?>" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="header-wrapper">
	            <div class="wrapper">
	                <header class="page-header">
	                    <?php echo ultravel_custom_header_banner_title(); ?>
	                </header>

	                <?php ultravel_add_breadcrumb(); ?>
	            </div><!-- .wrapper -->
            </div><!-- .header-wrapper -->
        </div><!-- #page-site-header -->

	<?php
	}
endif;
add_action( 'ultravel_header_image_action', 'ultravel_header_image', 10 );

if ( ! function_exists( 'ultravel_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Ultravel 1.0.0
	 */
	function ultravel_add_breadcrumb() {
		$options = ultravel_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( ultravel_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * ultravel_simple_breadcrumb hook
				 *
				 * @hooked ultravel_simple_breadcrumb -  10
				 *
				 */
				do_action( 'ultravel_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;

if ( ! function_exists( 'ultravel_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'ultravel_content_end_action', 'ultravel_content_end', 10 );

if ( ! function_exists( 'ultravel_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'ultravel_footer', 'ultravel_footer_start', 10 );

if ( ! function_exists( 'ultravel_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_footer_site_info() {
		$options = ultravel_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );
		$theme_data = wp_get_theme();
		$copyright_text = $options['copyright_text'];
		?>
			<div class="site-info col-2">
                <div class="wrapper">
                    <span>
                    	<?php 
                    	echo ultravel_santize_allow_tag( $copyright_text ); 
                    	?>
                    	
						<?php echo esc_html__( ' | All Rights Reserved | ', 'ultravel' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'ultravel' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>' ?>
                	</span>
                    <span>
                    	<?php  
                    		wp_nav_menu(  array(
								'theme_location' => 'social',
								'container' => false,
								'menu_class' => 'social-icons',
								'echo' => true,
								'depth' => 1,
								'link_before' => '<span class="screen-reader-text">',
								'link_after' => '</span>',
								'fallback_cb' => false,
							) );
                    	?>
                    </span>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'ultravel_footer', 'ultravel_footer_site_info', 40 );

if ( ! function_exists( 'ultravel_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_footer_scroll_to_top() {
		$options  = ultravel_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo ultravel_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'ultravel_footer', 'ultravel_footer_scroll_to_top', 40 );

if ( ! function_exists( 'ultravel_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'ultravel_footer', 'ultravel_footer_end', 100 );

if ( ! function_exists( 'ultravel_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_loader() {
		$options = ultravel_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo ultravel_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'ultravel_before_header', 'ultravel_loader', 10 );

if ( ! function_exists( 'ultravel_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Ultravel 1.0.0
	 *
	 */
	function ultravel_infinite_loader_spinner() { 
		global $post;
		$options = ultravel_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( $post ) > 0 ) {
				echo '<div class="blog-loader">' . ultravel_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'ultravel_infinite_loader_spinner_action', 'ultravel_infinite_loader_spinner', 10 );
